package com.game.business.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.game.business.domain.AppUsersAuth;
import com.game.business.vo.AppAnchorStarVo;
import org.apache.ibatis.annotations.Select;

/**
 * 主播认证Mapper接口
 *
 * @author game
 * @date 2024-08-11
 */
public interface AppUsersAuthMapper extends BaseMapper<AppUsersAuth> {
    /**
     * 查询主播认证
     *
     * @param uid 主播认证主键
     * @return 主播认证
     */
    public AppUsersAuth selectAppUsersAuthByUid(Long uid);

    /**
     * 查询主播认证列表
     *
     * @param appUsersAuth 主播认证
     * @return 主播认证集合
     */
    public List<AppUsersAuth> selectAppUsersAuthList(AppUsersAuth appUsersAuth);

    /**
     * 新增主播认证
     *
     * @param appUsersAuth 主播认证
     * @return 结果
     */
    public int insertAppUsersAuth(AppUsersAuth appUsersAuth);

    /**
     * 修改主播认证
     *
     * @param appUsersAuth 主播认证
     * @return 结果
     */
    public int updateAppUsersAuth(AppUsersAuth appUsersAuth);

    /**
     * 删除主播认证
     *
     * @param uid 主播认证主键
     * @return 结果
     */
    public int deleteAppUsersAuthByUid(Long uid);

    /**
     * 批量删除主播认证
     *
     * @param uids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAppUsersAuthByUids(Long[] uids);

    @Select("select id as id, star_name as name from app_anchor_star order by star_grade asc")
    public List<AppAnchorStarVo> selectAnchorStar();
}